Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client is a client for interacting with the HashiCorp Releases API
func (*Client) GetVersion ¶
GetVersion returns a specific release for a product from the HashiCorp Releases API
func (*Client) ListProducts ¶
ListProducts returns a list of products available from the HashiCorp Releases API
func (*Client) ListReleases ¶
func (c *Client) ListReleases(ctx context.Context, product string, opts *ListReleasesOptions) ([]*Release, error)
ListReleases returns a list of releases for a product from the HashiCorp Releases API
type ListReleasesOptions ¶
ListReleasesOptions are options for listing releases
type Release ¶
type Release struct {
Builds []*Build `json:"builds"`
DockerNameTag string `json:"docker_name_tag"`
IsPrerelease bool `json:"is_prerelease"`
LicenseClass string `json:"license_class"`
Name string `json:"name"`
Status Status `json:"status"`
TimestampCreated time.Time `json:"timestamp_created"`
TimestampUpdated time.Time `json:"timestamp_updated"`
URLBlogpost string `json:"url_blogpost"`
URLChangelog string `json:"url_changelog"`
URLDockerRegistryDockerhub string `json:"url_docker_registry_dockerhub"`
URLDockerRegistryEcr string `json:"url_docker_registry_ecr"`
URLLicense string `json:"url_license"`
URLProjectWebsite string `json:"url_project_website"`
URLReleaseNotes string `json:"url_release_notes"`
URLShasums string `json:"url_shasums"`
URLShasumsSignatures []string `json:"url_shasums_signatures"`
URLSourceRepository string `json:"url_source_repository"`
Version string `json:"version"`
}
Click to show internal directories.
Click to hide internal directories.